@@ -28,10 +28,11 @@ def table_col_as_computable(col: ColumnDefinition) -> Union[Attribute, Metric]:
 def column_data_type_for(attribute: Optional[CatalogAttribute]) -> str:
     """
     Determine what postgres type should be used for `attribute`.
+
     :param attribute: catalog attribute instance
     """
     if not attribute:
         return Converter.DEFAULT_DB_DATA_TYPE
 
-    converter = AttributeConverterStore.find_converter(attribute.dataset.data_type, attribute.granularity)
+    converter = AttributeConverterStore.find_converter(attribute.dataset.dataset_type, attribute.granularity)
     return converter.db_data_type()
